@@ -21,7 +21,11 @@
 */
 
 #include <config.h>
+#ifdef GNOME_GTKHTML_EDITOR_SHLIB
+#include <glib/gi18n-lib.h>
+#else
 #include <glib/gi18n.h>
+#endif
 #include <string.h>
 #include <bonobo.h>
 
@@ -283,5 +287,12 @@ editor_engine_new (GtkHTMLControlData *cd)
 
 	ee->cd = cd;
 
+	/* This engine will be returned to the composer window.
+	 * The html-widget will be used by the composer to 
+	 * provide DnD to the composer window's GtkHTML component
+	 */
+
+	g_object_set_data (ee, "html-widget", cd->html);
+	
 	return ee;
 }
