@@ -22,7 +22,11 @@
 
 
 #include <config.h>
+#ifdef GNOME_GTKHTML_EDITOR_SHLIB
+#include <glib/gi18n-lib.h>
+#else
 #include <glib/gi18n.h>
+#endif
 #include <libgnomeui/gnome-window-icon.h>
 #include "dialog.h"
 #include "properties.h"
@@ -62,7 +66,7 @@ switch_page (GtkWidget *w, GtkNotebookPage *page, gint num, GtkHTMLEditPropertie
 		pd = (PageData *) g_list_nth (d->page_data, num)->data;
 		if (pd) {
 			gchar *title;
-			title = g_strconcat (d->title, ": ", pd->name, NULL);
+			title = g_strconcat (d->title, " ", pd->name, NULL);
 			gtk_window_set_title (GTK_WINDOW (d->dialog), title);
 			g_free (title);
 		}
