@@ -104,6 +104,8 @@ url_requested (GtkHTML *html, const gchar *url, GtkHTMLStream *handle)
 	} else
 		status = GTK_HTML_STREAM_ERROR;
 	gtk_html_end (html, handle, status);
+	if (fd > 0)
+		close (fd);
 }
 
 GtkWidget *
